==> react-bootstrap-error-boundary-1.0.0.tgz: package/lib/esm/ErrorBoundary.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import React, { PureComponent } from 'react';
import Alert from 'react-bootstrap/Alert';
var ErrorBoundary = /** @class */ (function (_super) {
    __extends(ErrorBoundary, _super);
    function ErrorBoundary() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = {
            error: null,
            hasError: false,
        };
        return _this;
    }
    ErrorBoundary.getDerivedStateFromError = function (error) {
        return { hasError: true, error: error };
    };
    ErrorBoundary.prototype.componentDidCatch = function (error, errorInfo) {
        this.setState({ error: error, hasError: true });
        if (this.props.logToConsole) {
            console.log(error);
            console.log(errorInfo);
        }
    };
    ErrorBoundary.prototype.render = function () {
        if (this.state.hasError) {
            return React.createElement(Alert, { variant: this.props.variant }, this.props.textOnError(this.state.error));
        }
        return this.props.children;
    };
    ErrorBoundary.defaultProps = {
        logToConsole: true,
        textOnError: function (error) { return React.createElement(React.Fragment, null,
            'Error occured: ',
            typeof error.message === 'string'
                ? error.message
                : JSON.stringify(error)); },
        variant: 'danger',
    };
    return ErrorBoundary;
}(PureComponent));
export default ErrorBoundary;

==> react-bootstrap-error-boundary-2.0.0.tgz: package/lib/esm/ErrorBoundary.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import React, { PureComponent } from 'react';
import Alert from 'react-bootstrap/Alert';
var ErrorBoundary = /** @class */ (function (_super) {
    __extends(ErrorBoundary, _super);
    function ErrorBoundary() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.defaultErrorMessage = function (error) { return React.createElement(React.Fragment, null,
            _this.props.errorMessagePrefix,
            typeof error.message === 'string'
                ? error.message
                : JSON.stringify(error)); };
        _this.state = {
            error: null,
            hasError: false,
        };
        return _this;
    }
    ErrorBoundary.getDerivedStateFromError = function (error) {
        return { hasError: true, error: error };
    };
    ErrorBoundary.prototype.componentDidCatch = function (error, errorInfo) {
        this.setState({ error: error, hasError: true });
        if (this.props.logToConsole) {
            console.log(error);
            console.log(errorInfo);
        }
    };
    ErrorBoundary.prototype.render = function () {
        if (this.state.hasError) {
            return React.createElement(Alert, { variant: this.props.variant }, (this.props.errorMessage || this.defaultErrorMessage)(this.state.error));
        }
        return this.props.children;
    };
    ErrorBoundary.defaultProps = {
        errorMessagePrefix: 'Error occured: ',
        logToConsole: true,
        variant: 'danger',
    };
    return ErrorBoundary;
}(PureComponent));
export default ErrorBoundary;
